@@ -32,6 +32,7 @@ import argparse
 import inspect
 import traceback
 from types import ModuleType
+import pkg_resources
 
 from typing import (
     Any,
@@ -140,13 +141,35 @@ def get_module_class(modulelist: Union[Type['Module'], Text, Sequence[Union[Text
     return modules
 
 
-def load_module(moduleloader: Optional['ModuleParser'] = None) -> Type['argparse.Action']:
+def load_module(moduleloader: Optional['ModuleParser'] = None, entry_point_name: Optional[str] = None) -> Type['argparse.Action']:
     """Action, um Module mit der Methode "add_module" des ModuleParsers als Kommandozeilenparameter definieren zu können
     """
     class ModuleLoaderAction(argparse.Action):
         def __call__(self, parser: argparse.ArgumentParser, namespace: argparse.Namespace, values: Union[Text, Sequence[Any], None], option_string: Optional[Text] = None) -> None:
             if values:
-                values = get_module_class(values, moduleloader)
+                if entry_point_name:
+                    entry_point_list = []
+                    for entry_point in pkg_resources.iter_entry_points(entry_point_name):
+                        entry_point_list.append(entry_point.name)
+                        if entry_point.name == values:
+                            values = entry_point.load()
+                            break
+                        if entry_point.module_name == values:
+                            values = get_module_class(entry_point.module_name, moduleloader)
+                            break
+                    else:
+                        try:
+                            values = get_module_class(values, moduleloader)
+                        except Exception:
+                            raise argparse.ArgumentError(
+                                self,
+                                "Module '{}' not found! Valid modules are: {}".format(
+                                    values,
+                                    ", ".join(entry_point_list)
+                                )
+                            )
+                else:
+                    values = get_module_class(values, moduleloader)
                 setattr(namespace, self.dest, values[0] if values else None)
     return ModuleLoaderAction
 
@@ -227,7 +250,7 @@ class Module(metaclass=ClassPropertyMeta):
             logging.error('Baseclass %s mast be subclass of %s not %s', baseclass, Module, type(baseclass))
             raise ModuleError()
         # add "action" to new arguments
-        kwargs['action'] = load_module()
+        kwargs['action'] = load_module(entry_point_name=kwargs.get('dest'))
         if cls.MODULES is not None and cls.PARSER is not None:
             cls.MODULES.append((cls.PARSER.add_argument(*args, **kwargs), baseclass))
 
@@ -346,7 +369,7 @@ class ModuleParser(_ModuleArgumentParser):
             logging.error('Baseclass %s mast be subclass of %s not %s', baseclass, Module, type(baseclass))
             raise ModuleError()
         # add "action" to new arguments
-        kwargs['action'] = load_module(self)
+        kwargs['action'] = load_module(self, entry_point_name=kwargs.get('dest'))
         self._extra_modules.append((self.add_argument(*args, **kwargs), baseclass))
         logging.debug("Baseclass: %s", baseclass)
 
@@ -390,7 +413,12 @@ class ModuleParser(_ModuleArgumentParser):
         pass
 
     def _create_parser(self, args: Optional[Sequence[Text]] = None, namespace: Optional[argparse.Namespace] = None) -> 'argparse.ArgumentParser':
-        parsed_args, _ = super().parse_known_args(args=args, namespace=namespace)
+        parsed_args_tuple = super().parse_known_args(args=args, namespace=namespace)
+        if not parsed_args_tuple:
+            self.exit_on_error = False
+            super().parse_known_args(args=args, namespace=namespace)
+
+        parsed_args, _ = parsed_args_tuple
 
         # load modules from cmd args
         if self.baseclasses:
